==> xfxwidgets-1.9.99.tar.gz: lib/XF_ELENCO/XElencoXMedias.dart <==
import 'dart:typed_data';
import 'package:flutter/material.dart';
import 'package:observable/observable.dart';
import 'package:xfxbase/XFDataItem.dart';
import 'package:xfxbase/_XFX/XF_Col.dart';
import 'package:xfxbase/_XFX/XF_View.dart';
import 'package:xfxwidgets/xMediaItem.dart';
import 'package:xfxwidgets/xfxwidgets.dart';
import 'package:xtoolspackage/xtoolspackage.dart';
import 'XElenco.dart';

abstract class XViews {
  static XView _el_xmedias = XView("el_XMedias");
  static XView get el_XMedias {
    var _view = _el_xmedias;
    if (_view.cols.isEmpty) {
      _view.cols.add(XCol<String>("xDocType", "xDocType", 100, XMediaItem.xDocType_XP, format: "", headerToolTip: "nome del Attore (XDoc)", visiblePosition: 10, resizeStyle: 1, summarize: false, txtHAlign: Alignment.centerLeft, labelTxtHAlign: Alignment.center, readOnly: true));
    }
    return _view;
  }
}

class ElXBase_ElencoXMediaItem<T> extends XElenco<ElXBase_ElencoXMediaItem<T>, XMediaItem> {
  ElXBase_ElencoXMediaItem({
    Key? key,
    super.liXMediaToUse,
    Widget? xDrawerMenu,
    this.liToUse,
    super.xApp,
    Function(XMediaItem)? functToDelete,
    super.rootItemEdited,
    super.itemEdited,
    super.onTapItem,
    super.xBL_BTN_EmptyList,
    super.xCells_Item_Width,
    super.xCells_Item_Widget,
    super.xCells_Item_TextStyle,
  }) : super(
          'Medias',
          XViews.el_XMedias,
          pageMode_Active: true,
          liDetts: liToUse,
          onLongTapItem: functToDelete != null ? (item) => functToDelete(item) : null,
          xDrawerMenu: xDrawerMenu,
          key: key,
          title_Style: XStyles.xStyTextForTitle(textColor: XColors.foregroundLight),
          title_Color: (XColors.foregroundLight),
        );
  List<XMediaItem>? liToUse;
  Function(XMediaItem)? functToDelete;
  @override
  ElXBase_ElencoXMediaItem_State<T> createState() => ElXBase_ElencoXMediaItem_State<T>();
}

class ElXBase_ElencoXMediaItem_State<T> extends XElencoState<ElXBase_ElencoXMediaItem<T>, XMediaItem> {}

class ElencoXMediaItem<T> extends ElXBase_ElencoXMediaItem<T> {
  ElencoXMediaItem(this.obj, this.onGetXMedia, this.onSetXMedia, this.listPoolToTake, this.onDelXMedia, {this.isSch = false, Key? key, super.liXMediaToUse, super.xApp, super.liToUse, super.functToDelete, super.onTapItem, super.xBL_BTN_EmptyList, super.rootItemEdited, super.itemEdited, super.xCells_Item_Width, super.xCells_Item_Widget, super.xCells_Item_TextStyle}) : super(key: key);
  T? obj;
  Future<XMediaItem?> Function(XMediaItem) onGetXMedia;
  Future<String?>? Function(XMediaItem) onDelXMedia;
  Future Function(XMediaItem) onSetXMedia;
  ObservableList<XMediaItem> listPoolToTake;
  bool? isSch;
  @override
  _El_ElencoXMediaItem_State<T> createState() => _El_ElencoXMediaItem_State<T>();
}

class _El_ElencoXMediaItem_State<T> extends ElXBase_ElencoXMediaItem_State<T> {
  @override
  void initState() {
    widget.schedaMode = (widget as ElencoXMediaItem).isSch;
    widget.xApp = (widget as ElXBase_ElencoXMediaItem).xApp;
    widget.allowAdd = true;
    widget.xLayout_Stack_Alignment = Alignment.topCenter;
    super.initState();
    widget.onLongTapItem = (p0) async => await xOnDelXMedia(p0);
    widget.onTapBack = () => Navigator.pop(context);
    widget.cmd_Add = (p0) => super.xCMD_XMedia_GetMedia(setState, (widget as ElencoXMediaItem).obj!).then((value) => null).then((value) => initXFilters()).then((value) => rebuildAllChildren(context));
  }

  @override
  Future<XMediaItem?> xOnGetXMedia(XMediaItem xMedia) async {
    return (widget as ElencoXMediaItem).onGetXMedia(xMedia);
  }

  @override
  Future<bool?>? xOnDelXMedia(XMediaItem xMedia) async {
    if (xMedia.blobURL!.isNotEmpty) {
      await (widget as ElencoXMediaItem).onDelXMedia(xMedia)!.then((value) => value == "ok" ? true : false);
      setState(() {
        widget.liDetts!.remove(xMedia);
      });
      return true;
    } else {
      return false;
    }
  }

  @override
  Future<bool?>? xOnSaveXMedia(List<XMediaItem> liXMedia, XFDataItem item) async {
    for (var xm in liXMedia) {
      if ((widget as ElencoXMediaItem).listPoolToTake.any((element) => element.id == xm.id).not()) {
        xm.xDocID = item.id;
        xm.xDocType = item.X_docXObjectName;
        await (widget as ElencoXMediaItem).onSetXMedia(xm);
        setState(() {
          // widget.liDetts!.add(xm);
          (widget as ElencoXMediaItem).obj!.liXMedia!.add(xm);
        });
      }
    }
    return true;
  }

  @override
  Future<XMediaItem> xOnBefore_TakeXMedia(XMediaItem xclMedia, XFDataItem parent) async {
    if (parent is XMediaItem) {
      if (widget.liDetts!.isNotEmpty) {
        var li = widget.liDetts;
        if (li != null && li.isEmpty) {
          xclMedia.visPos = 0;
        } else {
          xclMedia.visPos = li!.last.visPos! + 10;
        }
      }
    }
    return xclMedia;
  }

  @override
  Future<Uint8List?>? xOnAfterXMedia_EditPhoto(XMediaItem xMedia) async {
    await (widget as ElencoXMediaItem).onSetXMedia(xMedia);
    return xMedia.payload;
  }

  @override
  Widget? xLayout_ItemWidget(XMediaItem xMedia) {
    var w = Container(
      child: InkWell(
          onLongPress: () => widget.onLongTapItem!(xMedia),
          onTap: () => xMedia.mediaType == XEnums.mediaType.image.value
              ? xCMD_XMedia_OpenPhoto(xMedia, (widget as ElencoXMediaItem).obj!)
              : xMedia.mediaType == XEnums.mediaType.video.value
                  ? xCMD_XMedia_OpenVideo(xMedia, pathPreviewVideo: xMedia.localURI!, setState: setState)
                  : xCMD_XMedia_OpenAudio(xMedia, (widget as ElencoXMediaItem).obj!, true),
          child: xMedia.mediaType == XEnums.mediaType.audio.value
              ? xLayout_Builder_AudioDialogWidget(xMedia, (widget as ElencoXMediaItem).obj!)
              : xMedia.mediaType == XEnums.mediaType.video.value
                  ? xLayout_Builder_VideoWidget(xMedia, xMedia, setState: setState)
                  : xLayout_Builder_ImmaginiWidget(xMedia, (widget as ElencoXMediaItem).obj!, setState)),
    );
    return w;
  }

  @override
  Widget xLayout_ElencoWidget() {
    return Container(
        margin: EdgeInsets.symmetric(vertical: 4, horizontal: 6),
        child: Wrap(
          spacing: 10,
          runSpacing: 10,
          children: widget.liDetts!.map((e) => xLayout_ItemWidget(e) ?? Container()).toList(),
        ));
  }
}

==> xfxwidgets-1.10.8.tar.gz: lib/XF_ELENCO/XElencoXMedias.dart <==
import 'dart:typed_data';
import 'package:flutter/material.dart';
import 'package:observable/observable.dart';
import 'package:xfxbase/XFDataItem.dart';
import 'package:xfxbase/_XFX/XF_Col.dart';
import 'package:xfxbase/_XFX/XF_View.dart';
import 'package:xfxwidgets/xMediaItem.dart';
import 'package:xfxwidgets/xfxwidgets.dart';
import 'package:xtoolspackage/xtoolspackage.dart';
import 'XElenco.dart';

abstract class XViews {
  static XView _el_xmedias = XView("el_XMedias");
  static XView get el_XMedias {
    var _view = _el_xmedias;
    if (_view.cols!.isEmpty) {
      _view.cols!.add(XCol<String>("xDocType", "xDocType", 100, XMediaItem.xDocType_XP, format: "", headerToolTip: "nome del Attore (XDoc)", visiblePosition: 10, resizeStyle: 1, summarize: false, txtHAlign: Alignment.centerLeft, labelTxtHAlign: Alignment.center, readOnly: true));
    }
    return _view;
  }
}

class ElXBase_ElencoXMediaItem<T> extends XElenco<ElXBase_ElencoXMediaItem<T>, XMediaItem> {
  ElXBase_ElencoXMediaItem({
    Key? key,
    super.liXMediaToUse,
    Widget? xDrawerMenu,
    this.liToUse,
    super.xApp,
    Function(XMediaItem)? functToDelete,
    super.rootItemEdited,
    super.itemEdited,
    super.onTapItem,
    super.xBL_BTN_EmptyList,
    super.xCells_Item_Width,
    super.xCells_Item_Widget,
    super.xCells_Item_TextStyle,
  }) : super(
          'Medias',
          XViews.el_XMedias,
          pageMode_Active: true,
          liDetts: liToUse,
          onLongTapItem: functToDelete != null ? (item) => functToDelete(item) : null,
          xDrawerMenu: xDrawerMenu,
          key: key,
          title_Style: XStyles.xStyTextForTitle(textColor: XColors.foregroundLight),
          title_Color: (XColors.foregroundLight),
        );
  List<XMediaItem>? liToUse;
  Function(XMediaItem)? functToDelete;
  @override
  ElXBase_ElencoXMediaItem_State<T> createState() => ElXBase_ElencoXMediaItem_State<T>();
}

class ElXBase_ElencoXMediaItem_State<T> extends XElencoState<ElXBase_ElencoXMediaItem<T>, XMediaItem> {}

class ElencoXMediaItem<T> extends ElXBase_ElencoXMediaItem<T> {
  ElencoXMediaItem(this.obj, this.onGetXMedia, this.onSetXMedia, this.listPoolToTake, this.onDelXMedia, {this.isSch = false, Key? key, super.liXMediaToUse, super.xApp, super.liToUse, super.functToDelete, super.onTapItem, super.xBL_BTN_EmptyList, super.rootItemEdited, super.itemEdited, super.xCells_Item_Width, super.xCells_Item_Widget, super.xCells_Item_TextStyle}) : super(key: key);
  T? obj;
  Future<XMediaItem?> Function(XMediaItem) onGetXMedia;
  Future<String?>? Function(XMediaItem) onDelXMedia;
  Future Function(XMediaItem) onSetXMedia;
  ObservableList<XMediaItem> listPoolToTake;
  bool? isSch;
  @override
  _El_ElencoXMediaItem_State<T> createState() => _El_ElencoXMediaItem_State<T>();
}

class _El_ElencoXMediaItem_State<T> extends ElXBase_ElencoXMediaItem_State<T> {
  @override
  void initState() {
    widget.schedaMode = (widget as ElencoXMediaItem).isSch;
    widget.xApp = (widget as ElXBase_ElencoXMediaItem).xApp;
    widget.allowAdd = true;
    widget.xLayout_Stack_Alignment = Alignment.topCenter;
    super.initState();
    widget.onLongTapItem = (p0) async => await xOnDelXMedia(p0);
    widget.onTapBack = () => Navigator.pop(context);
    widget.cmd_Add = (p0) => super.xCMD_XMedia_GetMedia(setState, (widget as ElencoXMediaItem).obj!).then((value) => null).then((value) => initXFilters()).then((value) => rebuildAllChildren(context));
  }

  @override
  Future<XMediaItem?> xOnGetXMedia(XMediaItem xMedia) async {
    return (widget as ElencoXMediaItem).onGetXMedia(xMedia);
  }

  @override
  Future<bool?>? xOnDelXMedia(XMediaItem xMedia) async {
    if (xMedia.blobURL!.isNotEmpty) {
      await (widget as ElencoXMediaItem).onDelXMedia(xMedia)!.then((value) => value == "ok" ? true : false);
      setState(() {
        widget.liDetts!.remove(xMedia);
      });
      return true;
    } else {
      return false;
    }
  }

  @override
  Future<bool?>? xOnSaveXMedia(List<XMediaItem> liXMedia, XFDataItem item) async {
    for (var xm in liXMedia) {
      if ((widget as ElencoXMediaItem).listPoolToTake.any((element) => element.id == xm.id).not()) {
        xm.xDocID = item.id;
        xm.xDocType = item.X_docXObjectName;
        await (widget as ElencoXMediaItem).onSetXMedia(xm);
        setState(() {
          // widget.liDetts!.add(xm);
          (widget as ElencoXMediaItem).obj!.liXMedia!.add(xm);
        });
      }
    }
    return true;
  }

  @override
  Future<XMediaItem> xOnBefore_TakeXMedia(XMediaItem xclMedia, XFDataItem parent) async {
    if (parent is XMediaItem) {
      if (widget.liDetts!.isNotEmpty) {
        var li = widget.liDetts;
        if (li != null && li.isEmpty) {
          xclMedia.visPos = 0;
        } else {
          xclMedia.visPos = li!.last.visPos! + 10;
        }
      }
    }
    return xclMedia;
  }

  @override
  Future<Uint8List?>? xOnAfterXMedia_EditPhoto(XMediaItem xMedia) async {
    await (widget as ElencoXMediaItem).onSetXMedia(xMedia);
    return xMedia.payload;
  }

  @override
  Widget? xLayout_ItemWidget(XMediaItem xMedia) {
    var w = Container(
      child: InkWell(
          onLongPress: () => widget.onLongTapItem!(xMedia),
          onTap: () => xMedia.mediaType == XEnums.mediaType.image.value
              ? xCMD_XMedia_OpenPhoto(xMedia, (widget as ElencoXMediaItem).obj!)
              : xMedia.mediaType == XEnums.mediaType.video.value
                  ? xCMD_XMedia_OpenVideo(xMedia, pathPreviewVideo: xMedia.localURI!, setState: setState)
                  : xCMD_XMedia_OpenAudio(xMedia, (widget as ElencoXMediaItem).obj!, true),
          child: xMedia.mediaType == XEnums.mediaType.audio.value
              ? xLayout_Builder_AudioDialogWidget(xMedia, (widget as ElencoXMediaItem).obj!)
              : xMedia.mediaType == XEnums.mediaType.video.value
                  ? xLayout_Builder_VideoWidget(xMedia, xMedia, setState: setState)
                  : xLayout_Builder_ImmaginiWidget(xMedia, (widget as ElencoXMediaItem).obj!, setState)),
    );
    return w;
  }

  @override
  Widget xLayout_ElencoWidget() {
    return Container(
        margin: EdgeInsets.symmetric(vertical: 4, horizontal: 6),
        child: Wrap(
          spacing: 10,
          runSpacing: 10,
          children: widget.liDetts!.map((e) => xLayout_ItemWidget(e) ?? Container()).toList(),
        ));
  }
}
